pub struct HttpRequest {
pub method: String,
pub url: Url,
pub headers: Vec<(String, String)>,
pub body: Vec<u8>,
}Expand description
An outgoing HTTP request.
Fields
method: Stringurl: Urlheaders: Vec<(String, String)>body: Vec<u8>Implementations
Sourceimpl HttpRequest
impl HttpRequest
Sourcepub fn to_http_10_vec(&self) -> Vec<u8> ⓘ
pub fn to_http_10_vec(&self) -> Vec<u8> ⓘ
Serialises this request as an HTTP/1.0 message; Content-Length is
regenerated from the body and any existing copy is dropped.
Sourceimpl HttpRequest
impl HttpRequest
Sourceimpl HttpRequest
impl HttpRequest
Sourcepub fn to_http_11_vec(&self) -> Vec<u8> ⓘ
pub fn to_http_11_vec(&self) -> Vec<u8> ⓘ
Serialises this request as an HTTP/1.1 message; Content-Length
is regenerated from the body and any existing copy is dropped.