pub struct StatusCode(pub u16);Expand description
HTTP status code.
Tuple Fields
0: u16Implementations
Sourceimpl StatusCode
impl StatusCode
Sourcepub fn is_success(self) -> bool
pub fn is_success(self) -> bool
Returns true if the status code is in the 2xx range.
Sourcepub fn is_redirection(self) -> bool
pub fn is_redirection(self) -> bool
Returns true if the status code is in the 3xx range.